==> python-dateparser-0.7.6-1-any.pkg.tar.xz: usr/lib/python3.8/site-packages/dateparser/data/date_translation_data/lv.py <==
# -*- coding: utf-8 -*-
info = {
    "name": "lv",
    "date_order": "DMY",
    "january": [
        "janvāris",
        "janv"
    ],
    "february": [
        "februāris",
        "febr"
    ],
    "march": [
        "marts"
    ],
    "april": [
        "aprīlis",
        "apr"
    ],
    "may": [
        "maijs"
    ],
    "june": [
        "jūnijs",
        "jūn"
    ],
    "july": [
        "jūlijs",
        "jūl"
    ],
    "august": [
        "augusts",
        "aug"
    ],
    "september": [
        "septembris",
        "sept"
    ],
    "october": [
        "oktobris",
        "okt"
    ],
    "november": [
        "novembris",
        "nov"
    ],
    "december": [
        "decembris",
        "dec"
    ],
    "monday": [
        "pirmdiena",
        "pirmd"
    ],
    "tuesday": [
        "otrdiena",
        "otrd"
    ],
    "wednesday": [
        "trešdiena",
        "trešd"
    ],
    "thursday": [
        "ceturtdiena",
        "ceturtd"
    ],
    "friday": [
        "piektdiena",
        "piektd"
    ],
    "saturday": [
        "sestdiena",
        "sestd"
    ],
    "sunday": [
        "svētdiena",
        "svētd"
    ],
    "am": [
        "priekšpusdiena",
        "priekšp",
        "priekšpusdienā"
    ],
    "pm": [
        "pēcpusdiena",
        "pēcpusd",
        "pēcpusdienā",
        "pēcp"
    ],
    "year": [
        "gads",
        "g"
    ],
    "month": [
        "mēnesis",
        "mēn"
    ],
    "week": [
        "nedēļa",
        "ned"
    ],
    "day": [
        "diena",
        "d"
    ],
    "hour": [
        "stundas",
        "st",
        "h"
    ],
    "minute": [
        "minūtes",
        "min"
    ],
    "second": [
        "sekundes",
        "sek",
        "s"
    ],
    "relative-type": {
        "1 year ago": [
            "pagājušajā gadā"
        ],
        "0 year ago": [
            "šajā gadā"
        ],
        "in 1 year": [
            "nākamajā gadā"
        ],
        "1 month ago": [
            "pagājušajā mēnesī"
        ],
        "0 month ago": [
            "šajā mēnesī"
        ],
        "in 1 month": [
            "nākamajā mēnesī"
        ],
        "1 week ago": [
            "pagājušajā nedēļā"
        ],
        "0 week ago": [
            "šajā nedēļā"
        ],
        "in 1 week": [
            "nākamajā nedēļā"
        ],
        "1 day ago": [
            "vakar"
        ],
        "0 day ago": [
            "šodien"
        ],
        "in 1 day": [
            "rīt"
        ],
        "0 hour ago": [
            "šajā stundā"
        ],
        "0 minute ago": [
            "šajā minūtē"
        ],
        "0 second ago": [
            "tagad"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "pēc (\\d+) gada",
            "pēc (\\d+) gadiem",
            "pēc (\\d+) g"
        ],
        "\\1 year ago": [
            "pirms (\\d+) gada",
            "pirms (\\d+) gadiem",
            "pirms (\\d+) g"
        ],
        "in \\1 month": [
            "pēc (\\d+) mēneša",
            "pēc (\\d+) mēnešiem",
            "pēc (\\d+) mēn"
        ],
        "\\1 month ago": [
            "pirms (\\d+) mēneša",
            "pirms (\\d+) mēnešiem",
            "pirms (\\d+) mēn"
        ],
        "in \\1 week": [
            "pēc (\\d+) nedēļas",
            "pēc (\\d+) nedēļām",
            "pēc (\\d+) ned"
        ],
        "\\1 week ago": [
            "pirms (\\d+) nedēļas",
            "pirms (\\d+) nedēļām",
            "pirms (\\d+) ned"
        ],
        "in \\1 day": [
            "pēc (\\d+) dienas",
            "pēc (\\d+) dienām",
            "pēc (\\d+) d"
        ],
        "\\1 day ago": [
            "pirms (\\d+) dienas",
            "pirms (\\d+) dienām",
            "pirms (\\d+) d"
        ],
        "in \\1 hour": [
            "pēc (\\d+) stundas",
            "pēc (\\d+) stundām",
            "pēc (\\d+) st",
            "pēc (\\d+) h"
        ],
        "\\1 hour ago": [
            "pirms (\\d+) stundas",
            "pirms (\\d+) stundām",
            "pirms (\\d+) st",
            "pirms (\\d+) h"
        ],
        "in \\1 minute": [
            "pēc (\\d+) minūtes",
            "pēc (\\d+) minūtēm",
            "pēc (\\d+) min"
        ],
        "\\1 minute ago": [
            "pirms (\\d+) minūtes",
            "pirms (\\d+) minūtēm",
            "pirms (\\d+) min"
        ],
        "in \\1 second": [
            "pēc (\\d+) sekundes",
            "pēc (\\d+) sekundēm",
            "pēc (\\d+) sek",
            "pēc (\\d+) s"
        ],
        "\\1 second ago": [
            "pirms (\\d+) sekundes",
            "pirms (\\d+) sekundēm",
            "pirms (\\d+) sek",
            "pirms (\\d+) s"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}

==> python-dateparser-1.1.1-1-any.pkg.tar.xz: usr/lib/python3.10/site-packages/dateparser/data/date_translation_data/lv.py <==
info = {
    "name": "lv",
    "date_order": "DMY",
    "january": [
        "janv",
        "janvāris"
    ],
    "february": [
        "febr",
        "februāris"
    ],
    "march": [
        "marts"
    ],
    "april": [
        "apr",
        "aprīlis"
    ],
    "may": [
        "maijs"
    ],
    "june": [
        "jūn",
        "jūnijs"
    ],
    "july": [
        "jūl",
        "jūlijs"
    ],
    "august": [
        "aug",
        "augusts"
    ],
    "september": [
        "sept",
        "septembris"
    ],
    "october": [
        "okt",
        "oktobris"
    ],
    "november": [
        "nov",
        "novembris"
    ],
    "december": [
        "dec",
        "decembris"
    ],
    "monday": [
        "pirmd",
        "pirmdiena"
    ],
    "tuesday": [
        "otrd",
        "otrdiena"
    ],
    "wednesday": [
        "trešd",
        "trešdiena"
    ],
    "thursday": [
        "ceturtd",
        "ceturtdiena"
    ],
    "friday": [
        "piektd",
        "piektdiena"
    ],
    "saturday": [
        "sestd",
        "sestdiena"
    ],
    "sunday": [
        "svētd",
        "svētdiena"
    ],
    "am": [
        "priekšp",
        "priekšpusdiena",
        "priekšpusdienā"
    ],
    "pm": [
        "pēcp",
        "pēcpusd",
        "pēcpusdiena",
        "pēcpusdienā"
    ],
    "year": [
        "g",
        "gads"
    ],
    "month": [
        "mēn",
        "mēnesis"
    ],
    "week": [
        "ned",
        "nedēļa"
    ],
    "day": [
        "d",
        "diena"
    ],
    "hour": [
        "h",
        "st",
        "stundas"
    ],
    "minute": [
        "min",
        "minūtes"
    ],
    "second": [
        "s",
        "sek",
        "sekundes"
    ],
    "relative-type": {
        "0 day ago": [
            "šodien"
        ],
        "0 hour ago": [
            "šajā stundā"
        ],
        "0 minute ago": [
            "šajā minūtē"
        ],
        "0 month ago": [
            "šajā mēnesī"
        ],
        "0 second ago": [
            "tagad"
        ],
        "0 week ago": [
            "šajā nedēļā"
        ],
        "0 year ago": [
            "šajā gadā"
        ],
        "1 day ago": [
            "vakar"
        ],
        "1 month ago": [
            "pagājušajā mēnesī"
        ],
        "1 week ago": [
            "pagājušajā nedēļā"
        ],
        "1 year ago": [
            "pagājušajā gadā"
        ],
        "in 1 day": [
            "rīt"
        ],
        "in 1 month": [
            "nākamajā mēnesī"
        ],
        "in 1 week": [
            "nākamajā nedēļā"
        ],
        "in 1 year": [
            "nākamajā gadā"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "pirms (\\d+) d",
            "pirms (\\d+) dienas",
            "pirms (\\d+) dienām"
        ],
        "\\1 hour ago": [
            "pirms (\\d+) h",
            "pirms (\\d+) st",
            "pirms (\\d+) stundas",
            "pirms (\\d+) stundām"
        ],
        "\\1 minute ago": [
            "pirms (\\d+) min",
            "pirms (\\d+) minūtes",
            "pirms (\\d+) minūtēm"
        ],
        "\\1 month ago": [
            "pirms (\\d+) mēn",
            "pirms (\\d+) mēneša",
            "pirms (\\d+) mēnešiem"
        ],
        "\\1 second ago": [
            "pirms (\\d+) s",
            "pirms (\\d+) sek",
            "pirms (\\d+) sekundes",
            "pirms (\\d+) sekundēm"
        ],
        "\\1 week ago": [
            "pirms (\\d+) ned",
            "pirms (\\d+) nedēļas",
            "pirms (\\d+) nedēļām"
        ],
        "\\1 year ago": [
            "pirms (\\d+) g",
            "pirms (\\d+) gada",
            "pirms (\\d+) gadiem"
        ],
        "in \\1 day": [
            "pēc (\\d+) d",
            "pēc (\\d+) dienas",
            "pēc (\\d+) dienām"
        ],
        "in \\1 hour": [
            "pēc (\\d+) h",
            "pēc (\\d+) st",
            "pēc (\\d+) stundas",
            "pēc (\\d+) stundām"
        ],
        "in \\1 minute": [
            "pēc (\\d+) min",
            "pēc (\\d+) minūtes",
            "pēc (\\d+) minūtēm"
        ],
        "in \\1 month": [
            "pēc (\\d+) mēn",
            "pēc (\\d+) mēneša",
            "pēc (\\d+) mēnešiem"
        ],
        "in \\1 second": [
            "pēc (\\d+) s",
            "pēc (\\d+) sek",
            "pēc (\\d+) sekundes",
            "pēc (\\d+) sekundēm"
        ],
        "in \\1 week": [
            "pēc (\\d+) ned",
            "pēc (\\d+) nedēļas",
            "pēc (\\d+) nedēļām"
        ],
        "in \\1 year": [
            "pēc (\\d+) g",
            "pēc (\\d+) gada",
            "pēc (\\d+) gadiem"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
